import { useState, useEffect } from "react";

export default function useProcessStatus(orderInfo) {
/**
 * 业务流程如下:
 * 1、农户下单 - 未支付 (管理端待分配订单)
 * 2、农机手待接单
 * 3、农机手接单干活
 * 4、农机手结单 - 确定亩数 (农户待支付)
 * 5、农户待评价
 * 6、结单(订单完成)
 */

  const [processStatus, setProcessStatus] = useState()

  useEffect(() => {
    if (!orderInfo || !orderInfo.orderId) return;

    setProcessStatus(getProcessStatus(orderInfo));
  }, [orderInfo])

  return { processStatus }
}

export function getProcessStatus(orderInfo) {
  
  if (!orderInfo || !orderInfo.orderId) return;

  // 订单完成
  if (orderInfo.isEvaluated) {
    return 6
  }
  
  // 待支付
  if (orderInfo.workStatus === 3 && orderInfo.charges > 0 && orderInfo.payStatus !== 1) {
    return 4
  }

  // 待评价
  if (orderInfo.workStatus === 3 && !orderInfo.isEvaluated) {
    return 5
  }

  // 工作中
  if (orderInfo.workStatus !== 3 && orderInfo.dispatchStatus) {
    return 3
  }

  // 待接单
  if (!orderInfo.workStatus && orderInfo.dispatchStatus) {
    return 2
  }

  // 待分配
  if (orderInfo.status === 1 && !orderInfo.dispatchStatus) {
    return 1
  }
  
  return -1
}

export function getProcessSignBy(status) {
  if (status === undefined || status === null) return {}
  
  switch (status) {
    case 1:
      return {
        label: '待分配',
        color: '#FF703B'
      }
    case 2:
      return {
        label: '待作业',
        color: '#FF703B'
      }
    case 3:
      return {
        label: '进行中',
        color: '#44F68B'
      }
    case 4:
      return {
        label: '待付款',
        color: '#51D4FF'
      }
    case 5:
      return {
        label: '待评价',
        color: '#51D4FF'
      }
    case 6:
      return {
        label: '已完成',
        color: '#FF703B'
      }
    default:
      return {
        label: '异常',
        color: '#FF0000'
      }
  }
}
